@@ -1,5 +1,5 @@
 import pytest
-from pyupbit.request_api import _parse_remaining_req
+from pyupbit.request_api import _parse
 from pyupbit.request_api import _call_public_api
 from pyupbit.errors import RemainingReqParsingError
 
@@ -11,7 +11,7 @@ def test_parse_remaining_req_defaults():
         'min': 573,
         'sec': 9
     }
-    ret = _parse_remaining_req(limit_info) 
+    ret = _parse(limit_info)
     assert ret == expected
 
 
@@ -19,12 +19,12 @@ def test_parse_remaining_req_raises():
     """_parse_remaining_req shold raise an exception with wrong parameter
     """
     with pytest.raises(RemainingReqParsingError):
-        _parse_remaining_req("")
+        _parse("")
 
 
 def test_call_public_api():
     url = "https://api.upbit.com/v1/market/all"
-    querystring = {"isDetails":"false"}
-    data, limit = _call_public_api(url, **querystring)
+    querystring = {"isDetails": "false"}
+    _, limit = _call_public_api(url, **querystring)
     assert isinstance(limit, dict)
 
